@@ -1,5 +1,8 @@
 from django.core.exceptions import ValidationError
-from django.utils.translation import ugettext as _, ungettext
+try:
+  from django.utils.translation import gettext as _, ngettext
+except ImportError:
+  from django.utils.translation import ugettext as _, ungettext as ngettext
 
 
 class PasswordCharacterValidator():
@@ -24,7 +27,7 @@ class PasswordCharacterValidator():
         validation_errors = []
         if len([char for char in password if char.isdigit()]) < self.min_length_digit:
             validation_errors.append(ValidationError(
-                ungettext(
+                ngettext(
                     'This password must contain at least %(min_length)d digit.',
                     'This password must contain at least %(min_length)d digits.',
                     self.min_length_digit
@@ -34,7 +37,7 @@ class PasswordCharacterValidator():
             ))
         if len([char for char in password if char.isalpha()]) < self.min_length_alpha:
             validation_errors.append(ValidationError(
-                ungettext(
+                ngettext(
                     'This password must contain at least %(min_length)d letter.',
                     'This password must contain at least %(min_length)d letters.',
                     self.min_length_alpha
@@ -44,7 +47,7 @@ class PasswordCharacterValidator():
             ))
         if len([char for char in password if char.isupper()]) < self.min_length_upper:
             validation_errors.append(ValidationError(
-                ungettext(
+                ngettext(
                     'This password must contain at least %(min_length)d upper case letter.',
                     'This password must contain at least %(min_length)d upper case letters.',
                     self.min_length_upper
@@ -54,7 +57,7 @@ class PasswordCharacterValidator():
             ))
         if len([char for char in password if char.islower()]) < self.min_length_lower:
             validation_errors.append(ValidationError(
-                ungettext(
+                ngettext(
                     'This password must contain at least %(min_length)d lower case letter.',
                     'This password must contain at least %(min_length)d lower case letters.',
                     self.min_length_lower
@@ -64,7 +67,7 @@ class PasswordCharacterValidator():
             ))
         if len([char for char in password if char in self.special_characters]) < self.min_length_special:
             validation_errors.append(ValidationError(
-                ungettext(
+                ngettext(
                     'This password must contain at least %(min_length)d special character.',
                     'This password must contain at least %(min_length)d special characters.',
                     self.min_length_special
@@ -79,7 +82,7 @@ class PasswordCharacterValidator():
         validation_req = []
         if self.min_length_alpha:
             validation_req.append(
-                ungettext(
+                ngettext(
                     "%(min_length)s letter",
                     "%(min_length)s letters",
                     self.min_length_alpha
@@ -87,7 +90,7 @@ class PasswordCharacterValidator():
             )
         if self.min_length_digit:
             validation_req.append(
-                ungettext(
+                ngettext(
                     "%(min_length)s digit",
                     "%(min_length)s digits",
                     self.min_length_digit
@@ -95,7 +98,7 @@ class PasswordCharacterValidator():
             )
         if self.min_length_lower:
             validation_req.append(
-                ungettext(
+                ngettext(
                     "%(min_length)s lower case letter",
                     "%(min_length)s lower case letters",
                     self.min_length_lower
@@ -103,7 +106,7 @@ class PasswordCharacterValidator():
             )
         if self.min_length_upper:
             validation_req.append(
-                ungettext(
+                ngettext(
                     "%(min_length)s upper case letter",
                     "%(min_length)s upper case letters",
                     self.min_length_upper
@@ -111,7 +114,7 @@ class PasswordCharacterValidator():
             )
         if self.special_characters:
             validation_req.append(
-                ungettext(
+                ngettext(
                     "%(min_length_special)s special character, such as %(special_characters)s",
                     "%(min_length_special)s special characters, such as %(special_characters)s",
                     self.min_length_special
